@@ -20,6 +20,8 @@ import io
 import base64
 from typing import List
 
+import requests
+
 from .exceptions import VideoUploadException
 from .exceptions import ResponseException
 from .exceptions import NetworkException
@@ -526,6 +528,8 @@ class Video:
         if date is not None:
             self.credential.raise_for_no_sessdata()
 
+        self.credential.raise_for_no_sessdata()
+
         if cid is None:
             if page_index is None:
                 raise ArgsException('page_index 和 cid 至少提供一个。')
@@ -731,6 +735,22 @@ class Video:
         }
         return await request("POST", url=api["url"], data=data, credential=self.credential)
 
+    
+    async def get_danmaku_xml(self, page_index):
+        """
+            获取所有弹幕的 xml 源文件（非装填）
+
+            Args:
+                page_index: 分 P 序号
+
+            Return:
+                xml 文件源
+        """
+        cid = await self.__get_page_id_by_index(page_index)
+        url = f"https://comment.bilibili.com/{cid}.xml"
+        res = requests.get(url)
+        return res.content
+
     async def like_danmaku(self, page_index: int = None, dmid: int = None, status: bool = True, cid: int = None):
         """
         点赞弹幕。
